StatsWindow = class(Turbine.UI.Lotro.Window)
 
local alphabetical_desc = { ["enum"] = 0, ["funct"] = function(w1,w2) return            w1.Name:GetText() < w2.Name:GetText()            end }
local alphabetical_asc  = { ["enum"] = 1, ["funct"] = function(w1,w2) return            w1.Name:GetText() > w2.Name:GetText()            end }
local kills_desc        = { ["enum"] = 2, ["funct"] = function(w1,w2) return tonumber(w1.Kills:GetText()) > tonumber(w2.Kills:GetText()) end }
local kills_asc         = { ["enum"] = 3, ["funct"] = function(w1,w2) return tonumber(w1.Kills:GetText()) < tonumber(w2.Kills:GetText()) end }

function StatsWindow:Constructor()

  local width = 250
  local height = 450
  local x = Turbine.UI.Display:GetWidth()/2 - width/2
  local y = Turbine.UI.Display:GetHeight()/2 - height/2

  Turbine.UI.Lotro.Window.Constructor(self)
  
  self:SetSize(width,height)
  self:SetPosition(x,y)
  self:SetZOrder(1)
  self:SetText(L.Statistics)
  self:SetWantsKeyEvents(true)

  ------------------------------------
  -------------- TABS ----------------
  ------------------------------------

  self.tab_stats = Tab(
    self, 1, 0, "PvMP_Plus/Resources/Tabs/stats.tga",
    "PvMP_Plus/Resources/Tabs/stats_mouseover.tga",
    "PvMP_Plus/Resources/Tabs/stats_selected.tga",
    "PvMP_Plus/Resources/Tabs/stats_selected_mouseover.tga"
  )
  self.tab_killList = Tab(
    self, 2, 1, "PvMP_Plus/Resources/Tabs/kills.tga",
    "PvMP_Plus/Resources/Tabs/kills_mouseover.tga",
    "PvMP_Plus/Resources/Tabs/kills_selected.tga",
    "PvMP_Plus/Resources/Tabs/kills_selected_mouseover.tga"
  )
  self.tab_barChart = Tab(
    self, 3, 2, "PvMP_Plus/Resources/Tabs/barChart.tga",
    "PvMP_Plus/Resources/Tabs/barChart_mouseover.tga",
    "PvMP_Plus/Resources/Tabs/barChart_selected.tga",
    "PvMP_Plus/Resources/Tabs/barChart_selected_mouseover.tga"
  )

  ------------------------------------
  ---------- STATS PANEL -------------
  ------------------------------------
  self.stats_panel = Turbine.UI.Control()
  self.stats_panel:SetParent(self)
  self.stats_panel:SetSize(self:GetWidth() - 50,self:GetHeight() - 90)
  self.stats_panel:SetPosition(self:GetWidth() / 2 - self.stats_panel:GetWidth() / 2,70)

  self.rank          = StatsLabel(self.stats_panel,0)
  self.commendations = StatsLabel(self.stats_panel,15)
  
  ---------- Points -------------
  self.points = Turbine.UI.Label()
  self.points:SetParent(self.stats_panel)
  self.points:SetSize(self.stats_panel:GetWidth(),20)
  self.points:SetPosition(0,40)
  self.points:SetForeColor(default_font_color)
  self.points:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
  self.points:SetFontStyle(Turbine.UI.FontStyle.Outline)
  self.points:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
  self.points:SetText(L.InfamyRenown)

  self.points_total      = StatsLabel(self.stats_panel,60)
  self.points_to_rankup  = StatsLabel(self.stats_panel,75)
  self.points_last_24h   = StatsLabel(self.stats_panel,90)
  self.points_this_day   = StatsLabel(self.stats_panel,105)
  self.points_last_hour  = StatsLabel(self.stats_panel,120)
  self.points_last_10min = StatsLabel(self.stats_panel,135)
  self.points_last_fight = StatsLabel(self.stats_panel,150)
  
  ---------- Frags -------------
  self.frags = Turbine.UI.Label()
  self.frags:SetParent(self.stats_panel)
  self.frags:SetSize(self.stats_panel:GetWidth(),20)
  self.frags:SetPosition(0,175)
  self.frags:SetForeColor(default_font_color)
  self.frags:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
  self.frags:SetFontStyle(Turbine.UI.FontStyle.Outline)
  self.frags:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
  self.frags:SetText(L.KillingBlows)
  
  self.frags_last_24h   = StatsLabel(self.stats_panel,195)
  self.frags_this_day   = StatsLabel(self.stats_panel,210)
  self.frags_last_hour  = StatsLabel(self.stats_panel,225)
  self.frags_last_10min = StatsLabel(self.stats_panel,240)
    
  ---------- Tracks -------------
  self.tracks = Turbine.UI.Label()
  self.tracks:SetParent(self.stats_panel)
  self.tracks:SetSize(self.stats_panel:GetWidth(),20)
  self.tracks:SetPosition(0,265)
  self.tracks:SetForeColor(default_font_color)
  self.tracks:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
  self.tracks:SetFontStyle(Turbine.UI.FontStyle.Outline)
  self.tracks:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
  self.tracks:SetText(L.Tracks)
  
  self.tracks_total      = StatsLabel(self.stats_panel,285)
  self.tracks_last_24h   = StatsLabel(self.stats_panel,300)
  self.tracks_this_day   = StatsLabel(self.stats_panel,315)
  self.tracks_last_hour  = StatsLabel(self.stats_panel,330)
  self.tracks_last_10min = StatsLabel(self.stats_panel,345)

  ------------------------------------
  ---------- FRAG PANEL --------------
  ------------------------------------
  self.frag_panel = Turbine.UI.Control()
  self.frag_panel:SetParent(self)
  self.frag_panel:SetSize(self:GetWidth() - 50,self:GetHeight() - 90)
  self.frag_panel:SetPosition(self:GetWidth() / 2 - self.frag_panel:GetWidth() / 2,70)

  self.search_box_label = Turbine.UI.Label()
  self.search_box_label:SetParent(self.frag_panel)
  self.search_box_label:SetSize(60, 20)
  self.search_box_label:SetPosition(0,3)
  self.search_box_label:SetForeColor(default_font_color)
  self.search_box_label:SetFont(Turbine.UI.Lotro.Font.TrajanPro18)
  self.search_box_label:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
  self.search_box_label:SetFontStyle(Turbine.UI.FontStyle.Outline)
  self.search_box_label:SetText(L.Search)
  
  self.search_box = Turbine.UI.Lotro.TextBox()
  self.search_box:SetParent(self.frag_panel)
  self.search_box:SetSize(self.frag_panel:GetWidth() - self.search_box_label:GetWidth(), 20)
  self.search_box:SetPosition(self.search_box_label:GetWidth(),3)
  self.search_box:SetForeColor(default_font_color)
  self.search_box:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
  self.search_box:SetMultiline(false)  
  self.search_box.TextChanged = function()
    self:UpdateFragList(self.current_sortmode)
  end
  
  self.frag_list = Turbine.UI.ListBox()
  self.frag_list:SetParent(self.frag_panel)
  self.frag_list:SetSize(self.frag_panel:GetWidth()-12,self.frag_panel:GetHeight() - 50)
  self.frag_list:SetPosition(0,45)

  self.scrollbar_fragList = Turbine.UI.Lotro.ScrollBar()
  self.scrollbar_fragList:SetParent(self.frag_panel)
  self.scrollbar_fragList:SetOrientation(Turbine.UI.Orientation.Vertical)
  self.scrollbar_fragList:SetSize(12,self.frag_list:GetHeight())
  self.scrollbar_fragList:SetPosition(self.frag_list:GetLeft() + self.frag_list:GetWidth(),self.frag_list:GetTop())
  self.frag_list:SetVerticalScrollBar(self.scrollbar_fragList)
  
  self.name_label = Turbine.UI.Label()
  self.name_label:SetParent(self.frag_panel)
  self.name_label:SetFont(Turbine.UI.Lotro.Font.TrajanPro16)
  self.name_label:SetSize(self.frag_list:GetWidth()/2, 20)
  self.name_label:SetPosition(0,25)
  self.name_label:SetForeColor(default_font_color)
  self.name_label:SetFontStyle(Turbine.UI.FontStyle.Outline)
  self.name_label:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
  self.name_label:SetText(L.Name)

  self.name_label.MouseDown = function()
    if self.current_sortmode == alphabetical_desc then
      self:SortFragList(alphabetical_asc)
    else
      self:SortFragList(alphabetical_desc)
    end
  end

  self.frags_label = Turbine.UI.Label()
  self.frags_label:SetParent(self.frag_panel)
  self.frags_label:SetFont(Turbine.UI.Lotro.Font.TrajanPro16)
  self.frags_label:SetSize(self.frag_list:GetWidth()/2, 20)
  self.frags_label:SetPosition(self.name_label:GetWidth(),25)
  self.frags_label:SetForeColor(default_font_color)
  self.frags_label:SetFontStyle(Turbine.UI.FontStyle.Outline)
  self.frags_label:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
  self.frags_label:SetText(L.AmountFrags)

  self.frags_label.MouseDown = function()
    if self.current_sortmode == kills_desc then
      self:SortFragList(kills_asc)
    else
      self:SortFragList(kills_desc)
    end
  end

  ------------------------------------
  --------- BAR CHART PANEL ----------
  ------------------------------------
  self.barChart_panel = Turbine.UI.Control()
  self.barChart_panel:SetParent(self)
  self.barChart_panel:SetSize(self:GetWidth() - 50,self:GetHeight() - 90)
  self.barChart_panel:SetPosition(self:GetWidth() / 2 - self.barChart_panel:GetWidth() / 2,70)

  ---------- Points-Diagram -------------
  self.barChart_points_heading = Turbine.UI.Label()
  self.barChart_points_heading:SetParent(self.barChart_panel)
  self.barChart_points_heading:SetSize(self.barChart_panel:GetWidth(),15)
  self.barChart_points_heading:SetForeColor(default_font_color)
  self.barChart_points_heading:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
  self.barChart_points_heading:SetFontStyle(Turbine.UI.FontStyle.Outline)
  self.barChart_points_heading:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
  self.barChart_points_heading:SetText(L.InfamyRenown)
  
  self.barChart_points = Turbine.UI.ListBox()
  self.barChart_points:SetParent(self.barChart_panel)
  self.barChart_points:SetSize(self.barChart_panel:GetWidth(),120)
  self.barChart_points:SetOrientation(Turbine.UI.Orientation.Horizontal)
  self.barChart_points:SetTop(self.barChart_points_heading:GetHeight())

  self.scrollbar_barChart = Turbine.UI.Lotro.ScrollBar()
  self.scrollbar_barChart:SetParent(self.barChart_panel)
  self.scrollbar_barChart:SetOrientation(Turbine.UI.Orientation.Vertical)
  self.scrollbar_barChart:SetSize(self.barChart_points:GetWidth(), 10)
  self.scrollbar_barChart:SetOrientation(Turbine.UI.Orientation.Horizontal)
  self.scrollbar_barChart:SetPosition(self.barChart_points:GetLeft(), self.barChart_points:GetTop() + self.barChart_points:GetHeight())
  self.barChart_points:SetHorizontalScrollBar(self.scrollbar_barChart)

  self.topline_points = Turbine.UI.Control()
  self.topline_points:SetParent(self.barChart_points)
  self.topline_points:SetSize(self.barChart_points:GetWidth(),1)
  self.topline_points:SetBackColor(Turbine.UI.Color.White)
  self.topline_points_label = Turbine.UI.Label()
  self.topline_points_label:SetParent(self.barChart_points)
  self.topline_points_label:SetFont(Turbine.UI.Lotro.Font.Verdana12)
  self.topline_points_label:SetText(topline_points_value)
  self.topline_points_label:SetSize(50,12)
  
  self.bottomline_points = Turbine.UI.Control()
  self.bottomline_points:SetParent(self.barChart_points)
  self.bottomline_points:SetSize(self.barChart_points:GetWidth(),1)
  self.bottomline_points:SetBackColor(Turbine.UI.Color.White)
  self.bottomline_points_label = Turbine.UI.Label()
  self.bottomline_points_label:SetParent(self.barChart_points)
  self.bottomline_points_label:SetFont(Turbine.UI.Lotro.Font.Verdana12)
  self.bottomline_points_label:SetSize(50,12)
  
  self.horiz_separator_points = Turbine.UI.Control()
  self.horiz_separator_points:SetParent(self.barChart_points)
  self.horiz_separator_points:SetSize(self.barChart_points:GetWidth(),1)
  self.horiz_separator_points:SetBackColor(Turbine.UI.Color.White)
  self.horiz_separator_points:SetTop(self.barChart_points:GetHeight() - 24)

  self.hopping_points = Turbine.UI.Label()
  self.hopping_points:SetParent(self)
  self.hopping_points:SetSize(40, 12)
  self.hopping_points:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
  self.hopping_points:SetFontStyle(Turbine.UI.FontStyle.Outline)
  self.hopping_points:SetOutlineColor(Turbine.UI.Color.Black)
  self.hopping_points:SetFont(Turbine.UI.Lotro.Font.Verdana12)
  self.hopping_points:SetVisible(false)
  
  self.most_points = Turbine.UI.Label()
  self.most_points:SetParent(self.barChart_panel)
  self.most_points:SetSize(self.barChart_panel:GetWidth(),12)
  self.most_points:SetTop(self.scrollbar_barChart:GetTop() + self.scrollbar_barChart:GetHeight() + 5)
  self.most_points:SetFont(Turbine.UI.Lotro.Font.Verdana12)
  self.most_points:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)

  ---------- Frag-Diagram -------------
  self.barChart_frags_heading = Turbine.UI.Label()
  self.barChart_frags_heading:SetParent(self.barChart_panel)
  self.barChart_frags_heading:SetSize(self.barChart_panel:GetWidth(),15)
  self.barChart_frags_heading:SetPosition(0,180)
  self.barChart_frags_heading:SetForeColor(default_font_color)
  self.barChart_frags_heading:SetFont(Turbine.UI.Lotro.Font.TrajanPro15)
  self.barChart_frags_heading:SetFontStyle(Turbine.UI.FontStyle.Outline)
  self.barChart_frags_heading:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
  self.barChart_frags_heading:SetText(L.KillingBlows)

  self.barChart_frags = Turbine.UI.ListBox()
  self.barChart_frags:SetParent(self.barChart_panel)
  self.barChart_frags:SetSize(self.barChart_panel:GetWidth(),120)
  self.barChart_frags:SetTop(self.barChart_frags_heading:GetTop() + self.barChart_frags_heading:GetHeight())
  self.barChart_frags:SetOrientation(Turbine.UI.Orientation.Horizontal)

  self.scrollbar_barChart2 = Turbine.UI.Lotro.ScrollBar()
  self.scrollbar_barChart2:SetParent(self.barChart_panel)
  self.scrollbar_barChart2:SetOrientation(Turbine.UI.Orientation.Vertical)
  self.scrollbar_barChart2:SetSize(self.barChart_frags:GetWidth(), 10)
  self.scrollbar_barChart2:SetOrientation(Turbine.UI.Orientation.Horizontal)
  self.scrollbar_barChart2:SetPosition(self.barChart_frags:GetLeft(), self.barChart_frags:GetTop() + self.barChart_frags:GetHeight())
  self.barChart_frags:SetHorizontalScrollBar(self.scrollbar_barChart2)

  self.topline_frags = Turbine.UI.Control()
  self.topline_frags:SetParent(self.barChart_frags)
  self.topline_frags:SetSize(self.barChart_frags:GetWidth(),1)
  self.topline_frags:SetBackColor(Turbine.UI.Color.White)
  self.topline_frags_label = Turbine.UI.Label()
  self.topline_frags_label:SetParent(self.barChart_frags)
  self.topline_frags_label:SetFont(Turbine.UI.Lotro.Font.Verdana12)
  self.topline_frags_label:SetText(topline_points_value)
  self.topline_frags_label:SetSize(50,12)
  
  self.bottomline_frags = Turbine.UI.Control()
  self.bottomline_frags:SetParent(self.barChart_frags)
  self.bottomline_frags:SetSize(self.barChart_frags:GetWidth(),1)
  self.bottomline_frags:SetBackColor(Turbine.UI.Color.White)
  self.bottomline_frags_label = Turbine.UI.Label()
  self.bottomline_frags_label:SetParent(self.barChart_frags)
  self.bottomline_frags_label:SetFont(Turbine.UI.Lotro.Font.Verdana12)
  self.bottomline_frags_label:SetSize(50,12)

  self.horiz_separator_frags = Turbine.UI.Control()
  self.horiz_separator_frags:SetParent(self.barChart_frags)
  self.horiz_separator_frags:SetSize(self.barChart_frags:GetWidth(),1)
  self.horiz_separator_frags:SetBackColor(Turbine.UI.Color.White)
  self.horiz_separator_frags:SetTop(self.barChart_frags:GetHeight() - 24)

  self.hopping_frags = Turbine.UI.Label()
  self.hopping_frags:SetParent(self)
  self.hopping_frags:SetSize(40, 12)
  self.hopping_frags:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
  self.hopping_frags:SetFontStyle(Turbine.UI.FontStyle.Outline)
  self.hopping_frags:SetOutlineColor(Turbine.UI.Color.Black)
  self.hopping_frags:SetFont(Turbine.UI.Lotro.Font.Verdana12)
  self.hopping_frags:SetVisible(false)

  self.most_frags = Turbine.UI.Label()
  self.most_frags:SetParent(self.barChart_panel)
  self.most_frags:SetSize(self.barChart_panel:GetWidth(),12)
  self.most_frags:SetTop(self.scrollbar_barChart2:GetTop() + self.scrollbar_barChart2:GetHeight() + 5)
  self.most_frags:SetFont(Turbine.UI.Lotro.Font.Verdana12)
  self.most_frags:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
  
  self.KeyDown = function(sender,args) 
    if args.Action == Turbine.UI.Lotro.Action.Escape then
      self:SetVisible(false)
    end
  end
end

function StatsWindow:UpdateStatsPanel()

  local tracksLast24h, tracksLastHour, tracksLast10Min = GetRecentData(data.numbers.recent_tracks)
  local fragsLast24h, fragsLastHour, fragsLast10Min = GetRecentData(data.numbers.recent_frags)
  
  local flag = true
	for i=0, 14 do
    if (data.numbers.points_total >= Ranks[i] and data.numbers.points_total < Ranks[i+1]) then
      self.rank:SetText(L.Strings_Rank..i)
      flag = false
      break
	  end
  end
  if flag then self.rank:SetText(L.Strings_Rank.."15") end

  self.points_total:SetText(L.Stats_Total .. FormatPoints(data.numbers.points_total))
  self.commendations:SetText(L.Commendations .. FormatPoints(current_commendations))
  self.points_to_rankup:SetText(L.Stats_To_RankUp .. FormatPoints(GetRemainingPoints()))
  self.points_this_day:SetText(L.Stats_Current_Day .. FormatPoints(data.numbers.points_current_day))
  self.points_last_24h:SetText(L.Stats_Last_24h .. pointsLast24h)
  self.points_last_hour:SetText(L.Stats_Last_Hour .. pointsLastHour)
  self.points_last_10min:SetText(L.Stats_Last_10min .. pointsLast10Min)
  self.points_last_fight:SetText(L.Stats_Last_Fight .. FormatPoints(points_last_fight))
  
  self.frags_this_day:SetText(L.Stats_Current_Day .. FormatPoints(data.numbers.frags_current_day))
  self.frags_last_24h:SetText(L.Stats_Last_24h .. fragsLast24h)
  self.frags_last_hour:SetText(L.Stats_Last_Hour .. fragsLastHour)
  self.frags_last_10min:SetText(L.Stats_Last_10min .. fragsLast10Min)
  
  self.tracks_total:SetText(L.Stats_Total .. FormatPoints(data.numbers.tracks_total))
  self.tracks_this_day:SetText(L.Stats_Current_Day .. FormatPoints(data.numbers.tracks_current_day))
  self.tracks_last_24h:SetText(L.Stats_Last_24h .. tracksLast24h)
  self.tracks_last_hour:SetText(L.Stats_Last_Hour .. tracksLastHour)
  self.tracks_last_10min:SetText(L.Stats_Last_10min .. tracksLast10Min)
end

function StatsWindow:UpdateFragList(sortmode)

  local totalFragAmount = 0
  local totalVictimAmount = 0
  local separatorColor = Turbine.UI.Color(30/255,30/255,30/255)
  local pattern = string.lower(self.search_box:GetText())
  self.frag_list:ClearItems()

  for name,frags in pairs(data.numbers.frags) do
    if string.match(string.lower(name), pattern) then
    
      totalVictimAmount = totalVictimAmount + 1
      totalFragAmount = totalFragAmount + frags
      
      local listItem = Turbine.UI.Control()
      listItem:SetSize(self.frag_list:GetWidth(), 15)

      listItem.Name = Turbine.UI.Label()
      listItem.Name:SetFont(Turbine.UI.Lotro.Font.Verdana14)
      listItem.Name:SetSize(self.frag_list:GetWidth()*3/4, listItem:GetHeight() - 1)
      listItem.Name:SetParent(listItem)
      listItem.Name:SetText(name)
      listItem.Kills = Turbine.UI.Label()
      listItem.Kills:SetFont(Turbine.UI.Lotro.Font.Verdana14)
      listItem.Kills:SetSize(self.frag_list:GetWidth()/4, listItem:GetHeight() - 1)
      listItem.Kills:SetParent(listItem)
      listItem.Kills:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
      listItem.Kills:SetText(frags)
      listItem.Kills:SetLeft(listItem.Name:GetWidth())
      listItem.separator = Turbine.UI.Control()
      listItem.separator:SetParent(listItem)
      listItem.separator:SetSize(listItem:GetWidth(), 1)
      listItem.separator:SetTop(14)
      listItem.separator:SetBackColor(separatorColor)
      self.frag_list:AddItem(listItem)
    end
	end

  self.name_label:SetText(L.Name.." ("..FormatPoints(totalVictimAmount)..")")
  self.frags_label:SetText(L.AmountFrags.." ("..FormatPoints(totalFragAmount)..")")

  self.frag_list:SetSelectedIndex(1)
  self:SortFragList(sortmode)
end

function StatsWindow:SortFragList(sortmode)

  self.frag_list:Sort(sortmode.funct)
  self.current_sortmode = sortmode
end

function StatsWindow:UpdateBarCharts()

  local daysToDisplay = 20
  local current_date = Turbine.Engine.GetDate()
  local barChartColor = Turbine.UI.Color(0.85,0.65,0.125)
  local points_last_days = {}
  local frags_last_days = {}
  local maxValue_points = { 0, nil, nil, nil }
  local maxValue_frags = { 0, nil, nil, nil }
  self.barChart_points:ClearItems()
  self.barChart_frags:ClearItems()

  for i=1, daysToDisplay - 1 do
    local dayOfYear = current_date.DayOfYear - i
    if dayOfYear < 1 then dayOfYear = dayOfYear + GetDaysPerYear(current_date.Year) end
    local points = data.numbers.history.points[dayOfYear]
    local frags = data.numbers.history.frags[dayOfYear]
    if dayOfYear == data.numbers.current_day then
      points = data.numbers.points_current_day
      frags = data.numbers.frags_current_day
    end
    local day = current_date.Day - i
    local month = current_date.Month
    local year = current_date.Year
    while day < 1 do
      month = month - 1
      if month == 0 then
        month = 12
        year = year - 1
      end
      day = GetDaysPerMonth(month) + day
    end

    if (points or 0) >= maxValue_points[1] then maxValue_points = { points or 0, day, month, year } end
    if (frags or 0)  >= maxValue_frags[1]  then maxValue_frags  = { frags  or 0, day, month, year } end
    points_last_days[daysToDisplay - i] = { day..".", L.Months[month], points or 0 }
    frags_last_days[daysToDisplay - i] = { day..".", L.Months[month], frags or 0 }
  end
  
  if data.numbers.current_day == current_date.DayOfYear then
    frags_last_days[daysToDisplay]  = { current_date.Day..".", L.Months[current_date.Month], data.numbers.frags_current_day  }
    points_last_days[daysToDisplay] = { current_date.Day..".", L.Months[current_date.Month], data.numbers.points_current_day }
  end

  if data.numbers.points_current_day >= maxValue_points[1] then
    maxValue_points = { data.numbers.points_current_day, current_date.Day, current_date.Month, current_date.Year }
  end
  if data.numbers.frags_current_day >= maxValue_frags[1] then
    maxValue_frags = { data.numbers.frags_current_day, current_date.Day, current_date.Month, current_date.Year }
  end

  maxValue_points = maxValue_points[1]
  maxValue_frags = maxValue_frags[1]
  ----------- Points -----------
  local diagramHeight = self.barChart_points:GetHeight() - 24

  if maxValue_points - math.floor(maxValue_points/1000)*1000 > 500 then
    maxValue_points = math.floor(maxValue_points/1000)*1000 + 1000
  end
  if maxValue_points < 1000 then maxValue_points = 1000 end
  
  local topline_points_value = math.floor(maxValue_points/1000)*1000

  if maxValue_points < math.floor(maxValue_points/1000) * 1000 + maxValue_points * 12/self.barChart_points:GetHeight() then
    maxValue_points = maxValue_points + maxValue_points * 12/self.barChart_points:GetHeight()
  end

  for index,points in pairs(points_last_days) do
    local listItem = Turbine.UI.Control()
    listItem:SetSize(self.barChart_points:GetWidth()/10.5 - 2, self.barChart_points:GetHeight())
    local subItem = Turbine.UI.Label()
    subItem:SetParent(listItem)
    subItem:SetBackColor(barChartColor)
    subItem:SetSize(listItem:GetWidth(), diagramHeight * (points[3]/maxValue_points))
    subItem:SetTop(diagramHeight - subItem:GetHeight())
    local points_amount = Turbine.UI.Label()
    points_amount:SetParent(listItem)
    points_amount:SetText(points[3])
    points_amount:SetVisible(false)
    subItem.MouseEnter = function()
      self.hopping_points:SetPosition(
        self.barChart_panel:GetLeft() + listItem:GetLeft() + listItem:GetWidth()/2 - self.hopping_points:GetWidth()/2,
        self.barChart_panel:GetTop() + self.barChart_points:GetTop() + subItem:GetTop() - self.hopping_points:GetHeight()
      )
      self.hopping_points:SetText(FormatPoints(points_amount:GetText()))
      self.hopping_points:SetVisible(true)
    end
    subItem.MouseLeave = function()
      self.hopping_points:SetVisible(false)
    end
    local dateItemDay = Turbine.UI.Label()
    dateItemDay:SetParent(listItem)
    dateItemDay:SetSize(listItem:GetWidth(), 12)
    dateItemDay:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
    dateItemDay:SetFont(Turbine.UI.Lotro.Font.Arial12)
    dateItemDay:SetText(points[1])
    dateItemDay:SetTop(listItem:GetHeight() - dateItemDay:GetHeight() * 2)
    local dateItemMonth = Turbine.UI.Label()
    dateItemMonth:SetParent(listItem)
    dateItemMonth:SetSize(listItem:GetWidth(), 12)
    dateItemMonth:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
    dateItemMonth:SetFont(Turbine.UI.Lotro.Font.Arial12)
    dateItemMonth:SetText(points[2])
    dateItemMonth:SetTop(listItem:GetHeight() - dateItemMonth:GetHeight())

    self.barChart_points:AddItem(listItem)

    local separator = Turbine.UI.Control()
    separator:SetSize(2, self.barChart_points:GetHeight())
    self.barChart_points:AddItem(separator)
  end
  self.barChart_points:RemoveItemAt(self.barChart_points:GetItemCount())

  local topline_points_value = topline_points_value
  self.topline_points:SetTop(diagramHeight - diagramHeight * topline_points_value/maxValue_points)
  self.topline_points_label:SetText(FormatPoints(topline_points_value))
  self.topline_points_label:SetTop(self.topline_points:GetTop() - 11)

  local bottomline_points_value = topline_points_value / 2
  self.bottomline_points:SetTop(diagramHeight - diagramHeight * bottomline_points_value/maxValue_points)
  self.bottomline_points_label:SetText(FormatPoints(bottomline_points_value))
  self.bottomline_points_label:SetTop(self.bottomline_points:GetTop() - 11)
    
  self.barChart_points:SetSelectedIndex(self.barChart_points:GetItemCount())

  self.most_points:SetText(L.Maximum..FormatPoints(data.numbers.most_points_a_day[1]).." ("..
  data.numbers.most_points_a_day[2]..". "..L.Months[data.numbers.most_points_a_day[3]].." "..data.numbers.most_points_a_day[4]..")")
  ----------- Frags -----------
  diagramHeight = self.barChart_frags:GetHeight() - 24

  if maxValue_frags - math.floor(maxValue_frags/10)*10 > 5 then
    maxValue_frags = math.floor(maxValue_frags/10)*10 + 10
  end
  if maxValue_frags < 10 then maxValue_frags = 10 end
  
  local topline_frags_value = math.floor(maxValue_frags/10)*10

  if maxValue_frags < math.floor(maxValue_frags/10) * 10 + maxValue_frags * 12/self.barChart_frags:GetHeight() then
    maxValue_frags = maxValue_frags + maxValue_frags * 12/self.barChart_frags:GetHeight()
  end
  
  for index,frags in pairs(frags_last_days) do
    local listItem = Turbine.UI.Control()
    listItem:SetSize(self.barChart_frags:GetWidth()/10.5 - 2, self.barChart_frags:GetHeight())
    local subItem = Turbine.UI.Label()
    subItem:SetParent(listItem)
    subItem:SetBackColor(barChartColor)
    subItem:SetSize(listItem:GetWidth(), diagramHeight * (frags[3]/maxValue_frags))
    subItem:SetTop(diagramHeight - subItem:GetHeight())
    local frags_amount = Turbine.UI.Label()
    frags_amount:SetParent(listItem)
    frags_amount:SetText(frags[3])
    frags_amount:SetVisible(false)
    subItem.MouseEnter = function()
      self.hopping_frags:SetPosition(
        self.barChart_panel:GetLeft() + listItem:GetLeft() + listItem:GetWidth()/2 - self.hopping_frags:GetWidth()/2,
        self.barChart_panel:GetTop() + self.barChart_frags:GetTop() + subItem:GetTop() - self.hopping_frags:GetHeight()
      )
      self.hopping_frags:SetText(frags_amount:GetText())
      self.hopping_frags:SetVisible(true)
    end
    subItem.MouseLeave = function()
      self.hopping_frags:SetVisible(false)
    end
    local dateItemDay = Turbine.UI.Label()
    dateItemDay:SetParent(listItem)
    dateItemDay:SetSize(listItem:GetWidth(), 12)
    dateItemDay:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
    dateItemDay:SetFont(Turbine.UI.Lotro.Font.Arial12)
    dateItemDay:SetText(frags[1])
    dateItemDay:SetTop(listItem:GetHeight() - dateItemDay:GetHeight() * 2)
    local dateItemMonth = Turbine.UI.Label()
    dateItemMonth:SetParent(listItem)
    dateItemMonth:SetSize(listItem:GetWidth(), 12)
    dateItemMonth:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
    dateItemMonth:SetFont(Turbine.UI.Lotro.Font.Arial12)
    dateItemMonth:SetText(frags[2])
    dateItemMonth:SetTop(listItem:GetHeight() - dateItemMonth:GetHeight())

    self.barChart_frags:AddItem(listItem)

    local separator = Turbine.UI.Control()
    separator:SetSize(2, self.barChart_frags:GetHeight())
    self.barChart_frags:AddItem(separator)
  end
  self.barChart_frags:RemoveItemAt(self.barChart_frags:GetItemCount())

  local topline_frags_value = topline_frags_value
  self.topline_frags:SetTop(diagramHeight - diagramHeight * topline_frags_value/maxValue_frags)
  self.topline_frags_label:SetText(topline_frags_value)
  self.topline_frags_label:SetTop(self.topline_frags:GetTop() - 11)

  local bottomline_frags_value = topline_frags_value / 2
  self.bottomline_frags:SetTop(diagramHeight - diagramHeight * bottomline_frags_value/maxValue_frags)
  self.bottomline_frags_label:SetText(bottomline_frags_value)
  self.bottomline_frags_label:SetTop(self.bottomline_frags:GetTop() - 11)
  
  self.barChart_frags:SetSelectedIndex(self.barChart_frags:GetItemCount())
  
  self.most_frags:SetText(L.Maximum..data.numbers.most_frags_a_day[1].." ("..
  data.numbers.most_frags_a_day[2]..". "..L.Months[data.numbers.most_frags_a_day[3]].." "..data.numbers.most_frags_a_day[4]..")")
end

function StatsWindow:ShowTab(tab)

  self.frag_panel:SetVisible(false)
  self.stats_panel:SetVisible(false)
  self.barChart_panel:SetVisible(false)

  if tab == self.tab_stats.index then
    self:UpdateStatsPanel()
    self.stats_panel:SetVisible(true)
  elseif tab == self.tab_killList.index then
    self.search_box:SetText("")
    self:UpdateFragList(kills_desc)
    self.frag_panel:SetVisible(true)
  elseif tab == self.tab_barChart.index then
    self:UpdateBarCharts()
    self.barChart_panel:SetVisible(true)
  end
end